@@ -29,18 +29,18 @@
 
 #include <curl/curl.h>
 
-#if !CURL_AT_LEAST_VERSION(7, 87, 0)
+#if !CURL_AT_LEAST_VERSION(7,87,0)
 #error "too old libcurl"
 #endif
 
 int main(void)
 {
   curl_version_info_data *ver;
-  const char * const *ptr;
+  const char *const *ptr;
 
-  CURLcode result = curl_global_init(CURL_GLOBAL_ALL);
-  if(result)
-    return (int)result;
+  CURLcode res = curl_global_init(CURL_GLOBAL_ALL);
+  if(res)
+    return (int)res;
 
   ver = curl_version_info(CURLVERSION_NOW);
   printf("Protocols:\n");
